%% Custom Spatial Transforms
% From _MATLAB Techniques for Image Processing_ by Steve Eddins.

%% How function handles work

f = @sin

%%
f(1)

%%
f(pi/2)

%%
integral(f,0,pi)

%%
% You can define your own spatial transform using |maketform('custom', ...)| and
% supplying function handles for doing the inverse and (optionally) the forward
% transform.
%
% Let's start with simple transform that just swaps the coordinates (u = y, v =
% x).

type transposeTform

%%
rgb = imread('liftingbody.png');
tform = transposeTform

%%
rgb2 = imtransform(rgb,tform);

subplot(1,2,1), imshow(rgb), xlabel('Image courtesy of NASA')
subplot(1,2,2), imshow(rgb2)

%%
% "Einstein Effect"
% See Beyond Photography: The Digital Darkroom, Gerard J. Holzmann, Prentice
% Hall, 1988, http://spinroot.com/pico/

type einsteinTform

%%
rgb = imread('moler.jpg');
rgb2 = imtransform(rgb,einsteinTform);

subplot(1,2,1), imshow(rgb)
subplot(1,2,2), imshow(rgb2)

%%
% Let's try a custom spatial transform with a more complicated use of extra
% data.

type randomWalkShearTform

%%

rgb = imread('loren.jpg');
rgb2 = imtransform(rgb,randomWalkShearTform(size(rgb)));

subplot(1,2,1),imshow(rgb)
subplot(1,2,2),imshow(rgb2)

%%

type blockShiftTform

%%

rgb = imread('jnl.jpg');
rgb2 = imtransform(rgb,blockShiftTform(size(rgb)));

subplot(1,2,1), imshow(rgb)
subplot(1,2,2), imshow(rgb2)

%%
% Finally, let's go back to polar coordinates and apply a twist by varying the
% angle in proportion to the radius.

type twistedTform

%%

rgb = imread('eddins.jpg');
rgb2 = imtransform(rgb,twistedTform(185,255,1));

subplot(1,2,1), imshow(rgb)
subplot(1,2,2), imshow(rgb2)

%%
% Copyright 2012-2014 The MathWorks, Inc.